@@ -143,15 +143,25 @@ class Model(_BaseGeometry):
                 allowed to differ from one another in order to consider them colinear.
                 Zero indicates that no angle tolerance checks should be performed.
                 Default: 0.
-        """
 
+        Returns:
+            A tuple with the two items below.
+
+            * model -- A dragonfly Model derived from the geoJSON.
+
+            * location -- A ladybug Location object, which contains latitude and
+                longitude information and can be used to re-serialize the model
+                back to geoJSON.
+        """
+        # parse the geoJSON into a dictionary
         with open(geojson_file_path, 'r') as fp:
             data = json.load(fp)
 
         # Get the list of building data
         if all_polygons_to_buildings:
-            bldgs_data = [bldg_data for bldg_data in data['features']
-                          if 'geometry' in bldg_data]
+            bldgs_data = \
+                [bldg_data for bldg_data in data['features'] if 'geometry' in bldg_data
+                 and bldg_data['geometry']['type'] in ('Polygon', 'MultiPolygon')]
         else:
             bldgs_data = []
             for bldg_data in data['features']:
@@ -160,8 +170,9 @@ class Model(_BaseGeometry):
                         bldgs_data.append(bldg_data)
 
         # Check if buildings exist
-        assert len(bldgs_data) > 0, 'No building footprints were found in {}. Check the ' \
-            'geometry coordinates in the file and if the "all_polygons_to_buildings" ' \
+        assert len(bldgs_data) > 0, 'No building footprints were found in {}. ' \
+            'Check the geometry coordinates in the file and if the ' \
+            '"all_polygons_to_buildings" ' \
             'argument is set correctly.'.format(geojson_file_path)
 
         # if model units is not Meters, convert non-meter user inputs to meters
@@ -173,19 +184,18 @@ class Model(_BaseGeometry):
         # model origin (point). If location is not passed by user, the coordinates are
         # taken or derived from the geojson file.
         if location is None:
+            point_lon_lat = None
             if 'project' in data:
                 proj_data = data['project']
                 if 'latitude' in proj_data and 'longitude' in proj_data:
                     point_lon_lat = (proj_data['latitude'], proj_data['longitude'])
-            else:
+            if point_lon_lat is None:
                 point_lon_lat = cls._bottom_left_coordinate_from_geojson(bldgs_data)
-        else:
-            point_lon_lat = (location.longitude, location.latitude)
+            location = Location(longitude=point_lon_lat[0], latitude=point_lon_lat[1])
 
         # The model point may not be at (0, 0), so shift the longitude and latitude to
         # get the equivalent point in longitude and latitude for (0, 0) in the model.
-        origin_lon_lat = origin_long_lat_from_location(
-            Location(longitude=point_lon_lat[0], latitude=point_lon_lat[1]), point)
+        origin_lon_lat = origin_long_lat_from_location(location, point)
         _convert_facs = meters_to_long_lat_factors(origin_lon_lat)
         convert_facs = 1 / _convert_facs[0], 1 / _convert_facs[1]
 
@@ -214,7 +224,9 @@ class Model(_BaseGeometry):
             if 'maximum_roof_height' in prop and 'number_of_stories' in prop:
                 story_height = prop["maximum_roof_height"] / prop['number_of_stories']
                 story_heights = [story_height] * prop['number_of_stories']
-            else:
+            elif 'number_of_stories' in prop:
+                story_heights = [3.5] * prop['number_of_stories']
+            else:  # just import it as one story per building
                 story_heights = [3.5]
 
             # Make Building object
@@ -235,14 +247,12 @@ class Model(_BaseGeometry):
         # Make model, in meters and then convert to user-defined units
         model = cls(model_id, buildings=bldgs, units='Meters',
                     tolerance=tolerance, angle_tolerance=angle_tolerance)
-
         if model_name:
             model.display_name = model_name
-
         if units != 'Meters':
             model.convert_to_units(units)
 
-        return model
+        return model, location
 
     @classmethod
     def from_dict(cls, data):
@@ -699,7 +709,7 @@ class Model(_BaseGeometry):
         convert_facs = meters_to_long_lat_factors(origin_lon_lat)
 
         # export each building as a feature in the file
-        for i, bldg in enumerate(model.buildings):
+        for _, bldg in enumerate(model.buildings):
             # create the base dictionary
             feature_dict = {'geometry': {}, 'properties': {}, 'type': 'Feature'}
 
@@ -839,7 +849,8 @@ class Model(_BaseGeometry):
         return coords
 
     @staticmethod
-    def _geojson_coordinates_to_face3d(geojson_coordinates, origin_lon_lat, convert_facs):
+    def _geojson_coordinates_to_face3d(geojson_coordinates, origin_lon_lat,
+                                       convert_facs):
         """Convert geoJSON coordinates to a horizontal Face3D with zero height.
 
         Args:
@@ -847,18 +858,18 @@ class Model(_BaseGeometry):
                 geometries, this will be the list from the 'coordinates' key in the
                 geojson file, for 'MultiPolygon' geometries, this will be each item
                 in the list from the 'coordinates' key.
-            origin_lon_lat: An array of two numbers in degrees representing the longitude
-                and latitude of the scene origin in degrees.
-            convert_facs: A tuple with two values used to translate between longitude, latitude
-                and meters.
+            origin_lon_lat: An array of two numbers in degrees representing the
+                longitude and latitude of the scene origin in degrees.
+            convert_facs: A tuple with two values used to translate between
+                longitude, latitude and meters.
 
         Returns:
-            A Face3D object in model space coordinates converted from the geojson coordinates.
-            The height of the Face3D vertices will be 0.
+            A Face3D object in model space coordinates converted from the geojson
+            coordinates. The height of the Face3D vertices will be 0.
         """
         holes = None
         coords = lon_lat_to_polygon(geojson_coordinates[0], origin_lon_lat, convert_facs)
-        coords = [Point3D(pt2d[0], pt2d[1], 0) for pt2d in coords][:-1]  # Remove redundant point
+        coords = [Point3D(pt2d[0], pt2d[1], 0) for pt2d in coords][:-1]
 
         # If there are more then 1 polygons, then the other polygons are holes.
         if len(geojson_coordinates) > 1:
